==> xwidgetsbase-1.4.1.tar.gz: lib/XStylesBase.dart <==
import 'package:flutter/material.dart';

class XStyles {
  /// fontSize 24
  static TextStyle xStyTextForLargeTitle([Color? textColor]) {
    return TextStyle(fontSize: 24, color: textColor ?? Colors.white);
  }

  /// fontSize 22
  static TextStyle xStyTextForTitle([Color? textColor]) {
    return TextStyle(fontSize: 22, color: textColor ?? Colors.white);
  }

  /// fontSize 20
  static TextStyle xStyTextForLabel([Color? textColor]) {
    return TextStyle(fontSize: 20, color: textColor ?? Colors.white);
  }

  /// fontSize 18
  static TextStyle xStyTextForTextBase([Color? textColor]) {
    return TextStyle(fontSize: 18, color: textColor ?? Colors.white);
  }

  /// fontSize 16
  static TextStyle xStyTextForDescr([Color? textColor]) {
    return TextStyle(fontSize: 16, color: textColor ?? Colors.white);
  }

  static TextStyle xStyleText({Color? colorText, double? fontSize, bool? activeBold = false, double? letterSpacing}) {
    return TextStyle(color: colorText ?? XColors.xcolor_ForegroundLight, fontSize: fontSize ?? 18, fontWeight: activeBold == false ? null : FontWeight.bold, letterSpacing: letterSpacing ?? 0);
  }
}

///////////  C O L O R S   B A S E  ///////////

class XColors {
  static final Color? primaryLight = Colors.white;
  static final Color? primaryDark = Colors.black;

//// THEME LIGHT ////
  static get xcolor_BackgroundLight => primaryLight;
  static get xcolor_ForegroundLight => primaryLight;

//// THEME DARK ////
  static get xcolor_BackgroundDark => primaryDark;
  static get xcolor_ForegroundDark => primaryDark;

//// THEME COLOR GENERAL ////
  static get xcolor_Done => Colors.greenAccent;
  static get xcolor_Undo => Colors.redAccent;
  static get xcolor_Warning => Colors.yellow;
  static get xcolor_BackGroungTitleDark => Colors.grey[800];
}

///////////  I C O N S   B A S E  ///////////

class XIcons {
  static get xicon_Done => Icons.done;
  static get xicon_Warning => Icons.warning;
  static get xicon_Delete => Icons.delete;
  static get xicon_Undo => Icons.undo;
  static get xicon_Refresh => Icons.refresh;
}

class XBoxDecoration {
  /////////// B A S E   D E C O R A T I O N S //////////

  /// BoxDecoration con border.all e di spessore 1 di colore se nullo bianco
  static xBoxDecorationStyleBorderAll({Color? color}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1));
  }

  static xBoxDecorationStyleCircular(Color? color) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1), borderRadius: BorderRadius.circular(20));
  }

  /// BoxDecoration con border.bottom e di spessore 1 di colore se nullo bianco
  static xBoxDecorationStyleEntryBorderBottom({Color? color}) {
    return BoxDecoration(border: Border(bottom: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// BoxDecoration con border.start e di spessore 1 di colore se nullo bianco
  static xBoxDecorationStyle_CellBorderStart({Color? color}) {
    return BoxDecoration(border: BorderDirectional(start: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// GREEN
  static xBoxDecoration_Gradient_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]));
  }

  static xBoxDecorationStyleCircular_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]), borderRadius: BorderRadius.circular(20));
  }

  static xBoxDecoration_Gradient_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]));
  }

  static xBoxDecorationStyleCircular_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]), borderRadius: BorderRadius.circular(20));
  }

  /// ORANGE

  static xBoxDecoration_Gradient_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]));
  }

  static xBoxDecorationStyleCircular_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]), borderRadius: BorderRadius.circular(20));
  }

  /// YELLOW

  static xBoxDecoration_Gradient_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]));
  }

  static xBoxDecorationStyleCircular_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]), borderRadius: BorderRadius.circular(20));
  }

  /// TEAL

  static xBoxDecoration_Gradient_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]));
  }

  static xBoxDecorationStyleCircular_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]), borderRadius: BorderRadius.circular(20));
  }

  /// GREY

  static xBoxDecoration_Gradient_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]));
  }

  static xBoxDecorationStyleCircular_Gradient_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]), borderRadius: BorderRadius.circular(20));
  }

  /// RED

  static xBoxDecoration_Gradient_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]));
  }

  static xBoxDecorationStyleCircular_Gradient_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]), borderRadius: BorderRadius.circular(20));
  }

  /// BLUE

  static xBoxDecoration_Gradient_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]));
  }

  static xBoxDecorationStyleCircular_Gradient_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(8));
  }

  /// PURPLE

  static xBoxDecoration_Gradient_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]));
  }

  static xBoxDecorationStyleCircular_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]), borderRadius: BorderRadius.circular(20));
  }
}

==> xwidgetsbase-1.4.2.tar.gz: lib/XStylesBase.dart <==
import 'package:flutter/material.dart';

class XStyles {
  /// fontSize 24
  static TextStyle xStyTextForLargeTitle([Color? textColor]) {
    return TextStyle(fontSize: 24, color: textColor ?? Colors.white);
  }

  /// fontSize 22
  static TextStyle xStyTextForTitle([Color? textColor]) {
    return TextStyle(fontSize: 22, color: textColor ?? Colors.white);
  }

  /// fontSize 20
  static TextStyle xStyTextForLabel([Color? textColor]) {
    return TextStyle(fontSize: 20, color: textColor ?? Colors.white);
  }

  /// fontSize 18
  static TextStyle xStyTextForTextBase([Color? textColor]) {
    return TextStyle(fontSize: 18, color: textColor ?? Colors.white);
  }

  /// fontSize 16
  static TextStyle xStyTextForDescr([Color? textColor]) {
    return TextStyle(fontSize: 16, color: textColor ?? Colors.white);
  }

  static TextStyle xStyleText({Color? colorText, double? fontSize, bool? activeBold = false, double? letterSpacing}) {
    return TextStyle(color: colorText ?? XColors.xcolor_ForegroundLight, fontSize: fontSize ?? 18, fontWeight: activeBold == false ? null : FontWeight.bold, letterSpacing: letterSpacing ?? 0);
  }
}

///////////  C O L O R S   B A S E  ///////////

class XColors {
  static final Color? primaryLight = Colors.white;
  static final Color? primaryDark = Colors.black;

//// THEME LIGHT ////
  static get xcolor_BackgroundLight => primaryLight;
  static get xcolor_ForegroundLight => primaryLight;

//// THEME DARK ////
  static get xcolor_BackgroundDark => primaryDark;
  static get xcolor_ForegroundDark => primaryDark;

//// THEME COLOR GENERAL ////
  static get xcolor_Done => Colors.greenAccent;
  static get xcolor_Undo => Colors.redAccent;
  static get xcolor_Warning => Colors.yellow;
  static get xcolor_BackGroungTitleDark => Colors.grey[800];
}

///////////  I C O N S   B A S E  ///////////

class XIcons {
  static get xicon_Done => Icons.done;
  static get xicon_Warning => Icons.warning;
  static get xicon_Delete => Icons.delete;
  static get xicon_Undo => Icons.undo;
  static get xicon_Refresh => Icons.refresh;
}

class XBoxDecoration {
  /////////// B A S E   D E C O R A T I O N S //////////

  /// BoxDecoration con border.all e di spessore 1 di colore se nullo bianco
  static xBoxDecorationStyleBorderAll({Color? color}) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1));
  }

  static xBoxDecorationStyleCircular(Color? color) {
    return BoxDecoration(border: Border.all(color: color ?? Colors.white, width: 1), borderRadius: BorderRadius.circular(20));
  }

  /// BoxDecoration con border.bottom e di spessore 1 di colore se nullo bianco
  static xBoxDecorationStyleEntryBorderBottom({Color? color}) {
    return BoxDecoration(border: Border(bottom: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// BoxDecoration con border.start e di spessore 1 di colore se nullo bianco
  static xBoxDecorationStyle_CellBorderStart({Color? color}) {
    return BoxDecoration(border: BorderDirectional(start: BorderSide(color: color ?? Colors.white, width: 1)));
  }

  /// GREEN
  static xBoxDecoration_Gradient_GreenAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]));
  }

  static xBoxDecorationStyleCircular_GreenAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF64DD17), Color(0xFF76FF03), Color(0xFFB2FF59)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  static xBoxDecoration_Gradient_GreenLightAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]));
  }

  static xBoxDecorationStyleCircular_GreenLightAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF00C853), Color(0xFF00E676), Color(0xFF69F0AE)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// ORANGE

  static xBoxDecoration_Gradient_OrangeAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]));
  }

  static xBoxDecorationStyleCircular_OrangeAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFF6D00), Color(0xFFFF9100), Color(0xFFFFAB40)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// YELLOW

  static xBoxDecoration_Gradient_Yellow() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]));
  }

  static xBoxDecorationStyleCircular_Yellow({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFFFC400), Color(0xFFFFD740)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// TEAL

  static xBoxDecoration_Gradient_Teal() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]));
  }

  static xBoxDecorationStyleCircular_Teal({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Colors.teal, Colors.teal[200]!]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// GREY

  static xBoxDecoration_Gradient_Grey() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]));
  }

  static xBoxDecorationStyleCircular_Gradient_Grey({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF616161), Color(0xFF757575), Color(0xFF9E9E9E)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// RED

  static xBoxDecoration_Gradient_RedAccent() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]));
  }

  static xBoxDecorationStyleCircular_Gradient_RedAccent({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFFDD2C00), Color(0xFFFF3D00), Color(0xFFBF360C)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }

  /// BLUE

  static xBoxDecoration_Gradient_Blue() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]));
  }

  static xBoxDecorationStyleCircular_Gradient_Blue({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF2962FF), Color(0xFF2979FF), Color(0xFF448AFF)]), border: Border.all(color: Colors.white, width: 1), borderRadius: BorderRadius.circular(borderRadius ?? 8));
  }

  /// PURPLE

  static xBoxDecoration_Gradient_Purple() {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]));
  }

  static xBoxDecorationStyleCircular_Purple({double? borderRadius}) {
    return BoxDecoration(gradient: LinearGradient(colors: <Color>[Color(0xFF4A148C), Color(0xFF6A1B9A), Color(0xFF7B1FA2), Color(0xFF8E24AA)]), borderRadius: BorderRadius.circular(borderRadius ?? 20));
  }
}
